@@ -180,9 +180,6 @@ def create_bucket(session, name=None, region=None):
     if region != 'us-east-1':
         params['CreateBucketConfiguration'] = {'LocationConstraint': region}
     try:
-        # To disable the (obsolete) awscli.errorhandler.ClientError behavior
-        client.meta.events.unregister(
-            'after-call', unique_id='awscli-error-handler')
         client.create_bucket(**params)
     except ClientError as e:
         if e.response['Error'].get('Code') == 'BucketAlreadyOwnedByYou':
